@@ -1,33 +1,54 @@
-
+import threading
 
 from sidecar.const import Const
 
 from sidecar.aws_status_maintainer import AWSStatusMaintainer
+from sidecar.sandbox_error import SandboxError
 
 
 class AWSStatusMaintainerMock(AWSStatusMaintainer):
+
+    default_table_attributes = [
+        {
+            'AttributeName': Const.SANDBOX_ID_TAG,
+            'AttributeType': 'S',
+        }
+    ]
+
+    default_table_schema = [
+        {
+            'AttributeName': Const.SANDBOX_ID_TAG,
+            'KeyType': 'HASH',
+        }
+    ]
+
+    default_table_provisioned_throughput = {
+        'ReadCapacityUnits': 25,
+        'WriteCapacityUnits': 25
+    }
+
     def __init__(self, sandbox_data):
+        self._apps_lock = threading.RLock()
+        self._logical_apps_lock = threading.RLock()
         if sandbox_data is not None:
             self.cached_sandbox_data = sandbox_data
         else:
-            self.cached_sandbox_data = {"spec": {
-                "expected_apps": {"1": {"apps": [], "instance_count": 1, Const.EXTERNAL_PORTS: {},
-                                        Const.INTERNAL_PORTS: {}},
-                                  "2": {"apps": [], "instance_count": 1, Const.EXTERNAL_PORTS: {},
-                                        Const.INTERNAL_PORTS: {}}}
-            }, "apps": {"1":
-                {"instances":
-                    {
+            self.cached_sandbox_data = {
+                "spec": {
+                    "expected_apps": {
+                        "1": {"apps": [], "instance_count": 1, Const.EXTERNAL_PORTS: {}, Const.INTERNAL_PORTS: {}},
+                        "2": {"apps": [], "instance_count": 1, Const.EXTERNAL_PORTS: {}, Const.INTERNAL_PORTS: {}}
                     }
                 },
-                "2":
-                    {"instances":
-                        {
-                        }
-                    }
-            }}
+                "apps": {
+                    "1": {"instances": {}},
+                    "2": {"instances": {}}
+                },
+                "logical-apps": {}
+            }
 
-        self.table_name = self.default_table_name
+    def _item_exist_in_db(self):
+        return True
 
     def add_sendboxdata_to_structure(self, sandboxid
                                      ):
@@ -54,7 +75,7 @@ class AWSStatusMaintainerMock(AWSStatusMaintainer):
     def refresh_sandbox_data(self, sandbox_id: str):
         return None
 
-    def getAllappNamesForInstance(self, logical_id: str):
+    def get_all_app_names_for_instance(self, logical_id: str):
         return self.cached_sandbox_data["spec"]["expected_apps"][logical_id]["apps"]
 
     def get_all_apps_for_logical_id(self, sandbox_id: str, logical_id: str):
@@ -101,7 +122,7 @@ class AWSStatusMaintainerMock(AWSStatusMaintainer):
         self.cached_sandbox_data["spec"]["expected_apps"][logical_id][Const.EXTERNAL_PORTS][
             app_name] = external_ports
 
-    def update_app_instance_status(self, instance_logical_id, instance_id, app_name, status_tag, status):
+    def update_app_instance_healthcheck_status(self, instance_logical_id, instance_id, app_name, status):
 
         if instance_id not in self.cached_sandbox_data["apps"][instance_logical_id]["instances"]:
             self.cached_sandbox_data["apps"][instance_logical_id]["instances"][instance_id] = \
@@ -110,7 +131,25 @@ class AWSStatusMaintainerMock(AWSStatusMaintainer):
                 }
 
         self.cached_sandbox_data["apps"][instance_logical_id]["instances"][instance_id]["apps"][app_name] = {
-            status_tag: status}
+            Const.APP_STATUS_TAG: status}
+
+    def add_app_instance_error(self, instance_logical_id, instance_id, app_name, error: SandboxError):
+        if instance_id not in self.cached_sandbox_data["apps"][instance_logical_id]["instances"]:
+            self.cached_sandbox_data["apps"][instance_logical_id]["instances"][instance_id] = \
+                {
+                    "apps": {}
+                }
+        self.cached_sandbox_data["apps"][instance_logical_id]["instances"][instance_id]["apps"]\
+            .setdefault(app_name, {})\
+            .setdefault(Const.APP_ERRORS, []).append(error)
+
+    def update_logical_app_healthcheck_status(self, app_name: str, status: str):
+        app_details = self.cached_sandbox_data["logical-apps"].setdefault(app_name, {})
+        app_details[Const.HEALTH_CHECK_STATUS] = status
+
+    def add_logical_app_error(self, app_name: str, error: SandboxError):
+        app_details = self.cached_sandbox_data["logical-apps"].setdefault(app_name, {})
+        app_details.setdefault(Const.APP_INSTANCE_ERRORS, []).append(error)
 
     def update_sandbox_end_status(self, sandbox_deployment_end_status: str):
         self.cached_sandbox_data[Const.SANDBOX_DEPLOYMENT_END_STATUS_v2] = sandbox_deployment_end_status
