@@ -1,5 +1,5 @@
 from logging import Logger
-from typing import Dict, List, Optional
+from typing import List, Optional
 
 from azure.mgmt.compute.v2017_03_30.models import Resource, VirtualMachineScaleSet
 from msrestazure.azure_exceptions import CloudError
@@ -8,13 +8,16 @@ from retrying import retry
 from sidecar.app_instance_identifier import AppInstanceIdentifier
 from sidecar.app_instance_service import IAppInstanceService
 from sidecar.azure_clp.azure_clients import AzureClientsManager
+from sidecar.azure_clp.azure_instance_power_state import AzureInstancePowerState
 from sidecar.azure_clp.azure_status_maintainer import AzureStatusMaintainer
 from sidecar.azure_clp.azure_tag_helper import AzureTagHelper
 from sidecar.azure_clp.retrying_helpers import retry_if_connection_error
 from sidecar.const import Const
+from sidecar.sandbox_error import SandboxError
 
 
 class AzureAppInstanceService(IAppInstanceService):
+
     def __init__(self,
                  logger: Logger,
                  sandbox_id: str,
@@ -25,16 +28,55 @@ class AzureAppInstanceService(IAppInstanceService):
         self._compute_client = clients_manager.compute_client
         self._status_maintainer = status_maintainer
 
-    def update_status_if_not_stale(self, app_instance_identifier: AppInstanceIdentifier, status: str):
-        vm_name = app_instance_identifier.infra_id
-        app_name = app_instance_identifier.name
-        vm_resource = self._get_existing_vm_resource(vm_name, app_name)
+    def get_public_address(self, app_instance_identifier: AppInstanceIdentifier) -> str:
+        # vm_resource = self._get_existing_vm_resource(vm_name=app_instance_identifier.infra_id,
+        #                                              app_name=app_instance_identifier.name)
+        return ''
 
-        instance_logical_id = AzureTagHelper.safely_get_tag(vm_resource, Const.INSTANCELOGICALID)
-        self._status_maintainer.update_app_instance_status(instance_logical_id=instance_logical_id,
-                                                           instance_id=vm_name,
-                                                           app_name=app_name,
-                                                           status=status)
+    def update_status_if_not_stale(self, app_instance_identifier: AppInstanceIdentifier, status: str):
+        logical_id = self._get_vm_logical_id(app_instance_identifier=app_instance_identifier)
+
+        self._status_maintainer.update_app_instance_healthcheck_status(
+            instance_logical_id=logical_id,
+            instance_id=app_instance_identifier.infra_id,
+            app_name=app_instance_identifier.name,
+            status=status)
+
+    def update_artifacts_status(self, app_instance_identifier: AppInstanceIdentifier, status: str):
+        logical_id = self._get_vm_logical_id(app_instance_identifier=app_instance_identifier)
+
+        self._status_maintainer.update_app_instance_artifacts_status(
+            instance_logical_id=logical_id,
+            instance_id=app_instance_identifier.infra_id,
+            app_name=app_instance_identifier.name,
+            status=status)
+
+    def update_configuration_status(self, app_instance_identifier: AppInstanceIdentifier, status: str):
+        logical_id = self._get_vm_logical_id(app_instance_identifier=app_instance_identifier)
+
+        self._status_maintainer.update_app_instance_configuration_status(
+            instance_logical_id=logical_id,
+            instance_id=app_instance_identifier.infra_id,
+            app_name=app_instance_identifier.name,
+            status=status)
+
+    def update_deployment_outputs(self, app_instance_identifier: AppInstanceIdentifier, outputs: {}):
+        logical_id = self._get_vm_logical_id(app_instance_identifier=app_instance_identifier)
+
+        self._status_maintainer.update_app_instance_outputs(
+            instance_logical_id=logical_id,
+            instance_id=app_instance_identifier.infra_id,
+            app_name=app_instance_identifier.name,
+            outputs=outputs)
+
+    def add_error(self, app_instance_identifier: AppInstanceIdentifier, error: SandboxError):
+        logical_id = self._get_vm_logical_id(app_instance_identifier=app_instance_identifier)
+
+        self._status_maintainer.add_app_instance_error(
+            instance_logical_id=logical_id,
+            instance_id=app_instance_identifier.infra_id,
+            app_name=app_instance_identifier.name,
+            error=error)
 
     def check_which_exist(self, identifiers: List[AppInstanceIdentifier]) -> List[AppInstanceIdentifier]:
         vm_names = list(set(identifier.infra_id for identifier in identifiers))
@@ -46,6 +88,27 @@ class AzureAppInstanceService(IAppInstanceService):
                                 if app_instance_identifier in identifiers]
         return existing_identifiers
 
+    def get_deployment_outputs(self, app_name: str) -> {}:
+        return self._status_maintainer.get_app_deployment_outputs(app_name)
+
+    def is_qualiy_off(self) -> bool:
+        try:
+            quali_vm_view = self._compute_client.virtual_machines.instance_view(resource_group_name=self._sandbox_id,
+                                                                                vm_name=Const.QUALY_SERVICE_NAME)
+            if len(quali_vm_view.statuses) > 1:
+                power_state = quali_vm_view.statuses[1].code
+                return power_state in [AzureInstancePowerState.DEALLOCATING, AzureInstancePowerState.STOPPED]
+        except CloudError as e:
+            if e.status_code != 404:
+                raise Exception('QualiY instance was not found')
+            raise
+
+    def _get_vm_logical_id(self, app_instance_identifier: AppInstanceIdentifier) -> str:
+        vm_resource = self._get_existing_vm_resource(vm_name=app_instance_identifier.infra_id,
+                                                     app_name=app_instance_identifier.name)
+        instance_logical_id = AzureTagHelper.safely_get_tag(vm_resource, Const.INSTANCELOGICALID)
+        return instance_logical_id
+
     def _get_existing_vm_resource(self, vm_name, app_name) -> Resource:
         vm_resource = self._try_get_vm_under_resource_group(vm_name)
         if vm_resource is None:
