@@ -1,6 +1,6 @@
 from logging import Logger
 
-from sidecar.app_configuration_start_policy import AppConfigurationStartPolicy
+from sidecar.configuration_start_policy import ConfigurationStartPolicy
 from sidecar.app_instance_config_status_event_reporter import AppInstanceConfigStatusEventReporter
 from sidecar.app_instance_service import IAppInstanceService
 from sidecar.app_services.app_service import AzureAppService
@@ -9,24 +9,29 @@ from sidecar.apps_configuration_end_tracker import AppsConfigurationEndTracker
 from sidecar.azure_clp.azure_app_instance_identifier_creator import AzureAppInstanceIdentifierCreator
 from sidecar.azure_clp.azure_app_instance_service import AzureAppInstanceService
 from sidecar.azure_clp.azure_clients import AzureClientsManager, AzureCredentialsProvider
-from sidecar.azure_clp.azure_cosmos_service import AzureCosmosService
 from sidecar.azure_clp.azure_sandbox_deployment_end_updater import AzureSandboxDeploymentEndUpdater
 from sidecar.azure_clp.azure_sandbox_start_time_updater import AzureSandboxStartTimeUpdater
 from sidecar.azure_clp.azure_status_maintainer import AzureStatusMaintainer
+from sidecar.azure_clp.azure_table_service import AzureTableService
 from sidecar.const import DateTimeProvider
 from sidecar.health_check.app_health_check_state import AppHealthCheckState
 from sidecar.model.objects import AzureSidecarConfiguration
 from sidecar.sandbox_deployment_end_updater import ISandboxDeploymentEndUpdater
 from sidecar.sandbox_deployment_state_tracker import SandboxDeploymentStateTracker
+from sidecar.services.metadata.azure_virtual_network_fetcher import AzureVirtualNetworkFetcher
+from sidecar.services.metadata.sandbox_public_address_fetcher import AzureSandboxPublicAddressFetcher
+from sidecar.services.service_status_state import ServiceStatusState
 
 
 class AzureSidecarApiInitializer:
     def __init__(self,
+                 service_execution_end_tracker: ServiceStatusState,
                  config: AzureSidecarConfiguration,
                  app_instance_status_event_reporter: AppInstanceConfigStatusEventReporter,
                  app_health_check_state: AppHealthCheckState,
                  logger: Logger) -> None:
         super().__init__()
+        self._service_execution_end_tracker = service_execution_end_tracker
         self._config = config
         self._app_health_check_state = app_health_check_state
         self._app_instance_status_event_reporter = app_instance_status_event_reporter
@@ -34,12 +39,21 @@ class AzureSidecarApiInitializer:
 
     def initialize(self):
         app_instance_identifier_creator = AzureAppInstanceIdentifierCreator(logger=self._logger)
-
         azure_credentials_provider = self._create_credentials_provider()
         azure_clients_manager = AzureClientsManager(credentials_provider=azure_credentials_provider)
-        azure_cosmos_service = AzureCosmosService(clients_manager=azure_clients_manager)
-        azure_status_maintainer = AzureStatusMaintainer(cosmos_service=azure_cosmos_service,
-                                                        sandbox_id=self._config.sandbox_id)
+
+        data_store_service = AzureTableService(azure_clients_manager.table_service)
+        data_store_service.create_table()
+
+        sandbox_public_address_fetcher = AzureSandboxPublicAddressFetcher(logger=self._logger,
+                                                                          sandbox_id=self._config.sandbox_id,
+                                                                          clients_manager=azure_clients_manager,
+                                                                          config=self._config)
+
+        azure_virtual_network_fetcher = AzureVirtualNetworkFetcher(self._config)
+        azure_status_maintainer = AzureStatusMaintainer(data_store_service=data_store_service,
+                                                        sandbox_id=self._config.sandbox_id,
+                                                        logger=self._logger)
 
         azure_app_instance_service = AzureAppInstanceService(logger=self._logger,
                                                              sandbox_id=self._config.sandbox_id,
@@ -66,7 +80,11 @@ class AzureSidecarApiInitializer:
             sandbox_deployment_end_updater=azure_sandbox_deployment_end_updater,
             apps_configuration_end_tracker=apps_configuration_end_tracker)
 
-        app_service = AzureAppService(logger=self._logger)
+        app_service = AzureAppService(logger=self._logger,
+                                      sandbox_id=self._config.sandbox_id,
+                                      production_id=self._config.production_id,
+                                      clients_manager=azure_clients_manager,
+                                      status_maintainer=azure_status_maintainer)
 
         return app_status_maintainer, \
                app_configuration_start_policy, \
@@ -74,7 +92,11 @@ class AzureSidecarApiInitializer:
                apps_configuration_end_tracker, \
                app_service, \
                sandbox_deployment_state_tracker, \
-               start_time_updater
+               start_time_updater, \
+               azure_status_maintainer,\
+               azure_app_instance_service, \
+               sandbox_public_address_fetcher, \
+               azure_virtual_network_fetcher
 
     def _create_apps_configuration_end_tracker(self, app_instance_service: IAppInstanceService):
         return AppsConfigurationEndTracker(logger=self._logger,
@@ -96,12 +118,15 @@ class AzureSidecarApiInitializer:
             app_instance_service=app_instance_service,
             apps_configuration_end_tracker=apps_configuration_end_tracker,
             sandbox_deployment_state_tracker=sandbox_deployment_state_tracker,
-            app_instance_status_event_reporter=self._app_instance_status_event_reporter)
+            app_instance_status_event_reporter=self._app_instance_status_event_reporter,
+            apps=self._config.apps)
 
-        app_configuration_start_policy = AppConfigurationStartPolicy(
+        app_configuration_start_policy = ConfigurationStartPolicy(
             app_health_check_state=self._app_health_check_state,
             apps_config_end_tracker=apps_configuration_end_tracker,
-            apps=self._config.apps)
+            apps=self._config.apps,
+            services=self._config.services,
+            service_status_state=self._service_execution_end_tracker)
 
         return app_status_maintainer, app_configuration_start_policy, sandbox_deployment_state_tracker
 
