@@ -1,9 +1,11 @@
-import time
 from logging import Logger
-from typing import List, Dict
+
+import time
+from typing import List
 
 from sidecar.const import Const
 from sidecar.file_system import FileSystemService
+from sidecar.health_check.app_health_check_configuration import AppHealthCheckConfiguration
 from sidecar.utils import CallsLogger
 
 
@@ -11,22 +13,23 @@ class HealthCheckPreparer:
     def __init__(self,
                  file_system: FileSystemService,
                  logger: Logger,
-                 default_ports: Dict[str, List[str]] = None):
+                 health_check_configuration: AppHealthCheckConfiguration):
+        self.health_check_configuration = health_check_configuration
         self._file_system = file_system
-        self._default_ports = default_ports
         self._logger = logger
 
-    def prepare(self, app_name: str, script_name: str, address: str):
-        if self._default_ports:
-            default_ports = self._default_ports.get(app_name)
-            if len(default_ports) > 0:
-                app_dir = Const.get_app_folder(app_name=app_name)
-                self._file_system.create_folder(app_dir)
-                return self._create_default_health_check_script(default_ports=default_ports,
-                                                                address=address,
-                                                                app_name=app_name)
+    def prepare(self, app_name: str, address: str):
+        health_check_configuration = self.health_check_configuration.get_configuration(app_name)
+        target_ports = health_check_configuration.target_ports
+        if target_ports:
+            app_dir = Const.get_app_folder(app_name=app_name)
+            self._file_system.create_folder(app_dir)
+            return self._create_default_health_check_script(default_ports=target_ports,
+                                                            address=address,
+                                                            app_name=app_name)
 
-        script_file_path = Const.get_health_check_file(app_name=app_name, script_name=script_name)
+        script_file_path = Const.get_health_check_file(app_name=app_name,
+                                                       script_name=health_check_configuration.script_name)
         return ['{script_file_path} {ip_address}'.format(
             script_file_path=script_file_path,
             ip_address=address)]
